@@ -1,4 +1,4 @@
-from .field import FormField, FormFieldInfo, FormFilter
+from .field import FormField, FormFieldData, FormFieldInfo, FormFilter
 from .filters import FormFilter
 from .form import Form, FormMeta
 from .state import FormState
